@@ -73,33 +73,31 @@ class ExponentialFamily(object):
     the above equation holds.
     They should also define some of the methods/attributes in the following sections.
 
-    Conversion
-    ==========
-            - theta(eta) : converts from natural parameters to canonical parameters
-            - x(T) : converts from canonical parameters to natural parameters if it differs from 0.0
-            - dimension : returns the length of eta and T
-            - normalisation_dimension : returns the length of A
+    *Conversion* methods include:
+    
+    - theta(eta) : converts from natural parameters to canonical parameters
+    - x(T) : converts from canonical parameters to natural parameters if it differs from 0.0
+    - dimension : returns the length of eta and T
+    - normalisation_dimension : returns the length of A
 
-    Sampling
-    ========
-    The following methods are optional:
-            - sample_theta(theta, size=1) : returns a sample from the distribution parameterised by theta
-            - sample_eta(eta, size=1) : returns a sample from the distribution parameterised by eta
+    The following *sampling* methods are optional:
 
-    Special
-    =======
-    The following methods are optional:
-            - exp_T(eta) : returns M{d(A)/d(eta)}, the derivative of the normalization factor with respect to
-            the natural parameter, evaluated at eta. This is equivalent to the expectation of T.
+    - sample_theta(theta, size=1) : returns a sample from the distribution parameterised by theta
+    - sample_eta(eta, size=1) : returns a sample from the distribution parameterised by eta
 
-    Testing
-    =======
-            - _p_truth(x, theta) : returns M{p(x|theta)} calculated by a different method
-            (e.g. scipy.stats) for testing
-            - _entropy_truth(theta) I{optional} : returns entropy of M{p(x|theta)} calculated by a different method
-            (e.g. scipy.stats) for testing
-            - _typical_xs : a sequence of typical x values for the family
-            - _typical_thetas : a sequence of typical theta values for the family
+    The following *special* methods are optional:
+    
+    - exp_T(eta) : returns M{d(A)/d(eta)}, the derivative of the normalization factor with respect to
+        the natural parameter, evaluated at eta. This is equivalent to the expectation of T.
+
+    *Testing* methods include:
+    
+    - _p_truth(x, theta) : returns M{p(x|theta)} calculated by a different method
+        (e.g. scipy.stats) for testing
+    - _entropy_truth(theta) I{optional} : returns entropy of M{p(x|theta)} calculated by a different method
+        (e.g. scipy.stats) for testing
+    - _typical_xs : a sequence of typical x values for the family
+    - _typical_thetas : a sequence of typical theta values for the family
     """
 
     def __init__(self, dimension, normalisation_dimension=1, vectorisable=False):
@@ -896,11 +894,12 @@ class WishartExpFamily(ExponentialFamily):
     The U{Wishart distribution<http://en.wikipedia.org/wiki/Wishart_distribution>} in p
     dimensions in exponential family form.
 
-            - T(W) = [log(det(W)), W.flatten]
-            - theta = (n, V) where n is the degrees of freedom and V, the scale matrix,
-            is typically regarded as the precision
-            - eta(theta) = [n-p-1, -inv(V).flatten()] / 2
-            - A(theta) = (n.p.log 2 + n.log det V) / 2 + log gamma_p (n/2)
+    - T(W) = [log(det(W)), W.flatten]
+    - theta = (n, V) where n is the degrees of freedom and V, the scale matrix,
+        is typically regarded as the precision
+    - eta(theta) = [n-p-1, -inv(V).flatten()] / 2
+    - A(theta) = (n.p.log 2 + n.log det V) / 2 + log gamma_p (n/2)
+    
     """
 
     _typical_xs = [
